#[non_exhaustive]pub enum EventBuilderError {
Clock(TimestampError),
Signer(UnsignedEventError),
}Expand description
Errors raised by EventBuilder terminal methods.
Variants (Non-exhaustive)
This enum is marked as non-exhaustive
Non-exhaustive enums could have additional variants added in future. Therefore, when matching against variants of non-exhaustive enums, an extra wildcard arm must be added to account for any future variants.
Clock(TimestampError)
The system clock could not be read while choosing created_at.
Signer(UnsignedEventError)
The signer’s public key did not match the supplied pubkey.