Event before its signature has been attached.
UnsignedEvent is the value handed to a signer (local Keys, NIP-46
remote signer, NIP-07 browser extension, …). The cryptographic identifier
is computed eagerly so the signer only needs to produce a 64-byte Schnorr
signature over id.
Structs
- Unsigned
Event - An event whose
idhas been computed but no signature attached.
Enums
- Unsigned
Event Error - Errors raised when signing an
UnsignedEvent.