Language

Enum Language 

pub enum Language {
    English,
}
Available on crate feature nip06 only.
Language to be used for the mnemonic phrase.

The English language is always available, other languages are enabled using the compilation features.

Variants



English

The English language.

Implementations

Source

impl Language

pub const ALL: &'static [Language]

The list of supported languages. Language support is managed by compile features.

pub fn all() -> &'static [Language]

👎Deprecated since 2.1.0:

use constant Language::ALL instead

The list of supported languages. Language support is managed by compile features.

pub fn word_list(self) -> &'static [&'static str; 2048]

The word list for this language.

pub fn words_by_prefix(self, prefix: &str) -> &[&'static str]

Get words from the word list that start with the given prefix.

pub fn find_word(self, word: &str) -> Option<u16>

Get the index of the word in the word list.