#[non_exhaustive]pub enum CommentError {
UnexpectedKind(u16),
MissingRoot,
MissingParent,
MissingValue {
tag: &'static str,
},
InvalidKind(String),
InvalidEventId(EventIdError),
InvalidCoordinate(CoordinateError),
InvalidRelay(RelayUrlError),
InvalidPubkey(PublicKeyError),
}Expand description
Errors raised when parsing a NIP-22 comment event.
Variants (Non-exhaustive)
This enum is marked as non-exhaustive
Non-exhaustive enums could have additional variants added in future. Therefore, when matching against variants of non-exhaustive enums, an extra wildcard arm must be added to account for any future variants.
UnexpectedKind(u16)
The event’s kind was not 1111.
MissingRoot
The event was missing a root scope tag (E/A/I).
MissingParent
The event was missing a parent scope tag (e/a/i).
MissingValue
A recognised tag was missing its value.
InvalidKind(String)
A K/k value did not parse as u16.
InvalidEventId(EventIdError)
An E/e tag’s id did not parse.
InvalidCoordinate(CoordinateError)
An A/a tag’s coordinate did not parse.
InvalidRelay(RelayUrlError)
A relay hint did not parse.
InvalidPubkey(PublicKeyError)
A P/p tag’s pubkey did not parse.