#[non_exhaustive]pub enum ChannelMetadataError {
InvalidJson(Error),
NotAnObject,
InvalidStringField {
key: &'static str,
actual: String,
},
InvalidRelaysField,
InvalidRelayUrl(RelayUrlError),
}Expand description
Errors raised while parsing channel metadata JSON or hide-reason JSON.
Variants (Non-exhaustive)
This enum is marked as non-exhaustive
Non-exhaustive enums could have additional variants added in future. Therefore, when matching against variants of non-exhaustive enums, an extra wildcard arm must be added to account for any future variants.
InvalidJson(Error)
The .content was not parseable JSON.
NotAnObject
The JSON was a valid value but not an object.
InvalidStringField
A spec-named string field was something other than a string.
Fields
InvalidRelaysField
relays was not an array of strings.
InvalidRelayUrl(RelayUrlError)
One of the relays[i] strings failed RelayUrl::parse.