pub struct LiveChatMessage {
pub content: String,
pub host: Coordinate,
pub host_relay_hint: Option<RelayUrl>,
pub host_marker: Option<String>,
pub parent_id: Option<EventId>,
pub parent_id_relay_hint: Option<RelayUrl>,
pub quote_id: Option<EventId>,
pub quote_id_relay_hint: Option<RelayUrl>,
pub quote_author: Option<PublicKey>,
pub extra_tags: Vec<Tag>,
}Expand description
Typed bundle for a kind: 1311 live chat message.
Fields
content: String.content body.
host: CoordinateRequired a tag pointing at the host event (30311 / 30313 /
30312).
host_relay_hint: Option<RelayUrl>Optional relay hint for the host coordinate.
host_marker: Option<String>Optional thread-marker on the host a tag (root, etc).
parent_id: Option<EventId>Optional e tag pointing at the parent chat message.
parent_id_relay_hint: Option<RelayUrl>Optional relay hint for Self::parent_id.
quote_id: Option<EventId>Optional q tag (NIP-21 citation).
quote_id_relay_hint: Option<RelayUrl>Optional relay hint for Self::quote_id.
Optional quoted-event author pubkey (4th column of q).
Forward-compatible passthrough for unknown tags.
Implementations