#[non_exhaustive]pub enum RelayDiscoveryError {
WrongKind(Kind),
MissingIdentifier,
InvalidNip(String),
InvalidAcceptedKind(String),
InvalidRtt(String),
InvalidFrequency(String),
MalformedTimeout,
InvalidTimeout(String),
}Expand description
Errors raised by NIP-66 parsers.
Variants (Non-exhaustive)
This enum is marked as non-exhaustive
Non-exhaustive enums could have additional variants added in future. Therefore, when matching against variants of non-exhaustive enums, an extra wildcard arm must be added to account for any future variants.
WrongKind(Kind)
The event did not match the expected NIP-66 kind.
MissingIdentifier
d tag is absent on a 30166 event.
InvalidNip(String)
N tag value could not be parsed as a u16.
InvalidAcceptedKind(String)
k tag value could not be parsed as a u16.
InvalidRtt(String)
rtt-* value could not be parsed as a u64.
InvalidFrequency(String)
frequency value could not be parsed as a u64.
MalformedTimeout
timeout tag is missing required columns.
InvalidTimeout(String)
timeout tag value could not be parsed as a u64.