#[non_exhaustive]pub enum VideoError {
Show 14 variants
WrongKind(Kind),
MissingIdentifier,
MissingTitle,
MissingMedia,
MalformedParticipant,
MalformedTextTrack,
MalformedSegment,
MalformedOrigin,
InvalidDuration(String),
Media(MediaAttachmentError),
InvalidPublicKey(PublicKeyError),
InvalidUrl(UrlError),
InvalidRelayUrl(RelayUrlError),
InvalidTimestamp(TimestampError),
}Expand description
Errors raised by NIP-71 parsers.
Variants (Non-exhaustive)
This enum is marked as non-exhaustive
Non-exhaustive enums could have additional variants added in future. Therefore, when matching against variants of non-exhaustive enums, an extra wildcard arm must be added to account for any future variants.
WrongKind(Kind)
Event kind is not one of the four NIP-71 kinds.
MissingIdentifier
Addressable event is missing its d tag.
MissingTitle
Required title tag is absent.
MissingMedia
Required imeta tag(s) are absent.
MalformedParticipant
p tag missing pubkey column.
MalformedTextTrack
text-track tag missing value column.
MalformedSegment
segment tag missing one of the required columns.
MalformedOrigin
origin tag missing one of the required columns.
InvalidDuration(String)
duration tag value could not be parsed as f64.
Media(MediaAttachmentError)
Wrapped imeta parser error.
InvalidPublicKey(PublicKeyError)
Wrapped pubkey parser error.
InvalidUrl(UrlError)
Wrapped URL parser error.
InvalidRelayUrl(RelayUrlError)
Wrapped relay-URL parser error.
InvalidTimestamp(TimestampError)
Wrapped timestamp parser error.