#[non_exhaustive]pub enum HttpAuthError {
Show 15 variants
WrongKind(Kind),
MissingUrl,
MissingMethod,
InvalidUrl(UrlError),
InvalidPayloadHashLength(usize),
InvalidPayloadHash(HexError),
HeaderWrongScheme,
HeaderInvalidBase64(DecodeError),
HeaderInvalidUtf8(Utf8Error),
HeaderInvalidEvent(EventError),
HeaderInvalidJson(Error),
ValidationTimestampSkew {
delta_secs: u64,
allowed_secs: u64,
},
ValidationUrlMismatch {
expected: String,
got: String,
},
ValidationMethodMismatch {
expected: String,
got: String,
},
ValidationPayloadMismatch,
}Expand description
Errors raised while building, parsing, or validating an HTTP-auth event.
Variants (Non-exhaustive)
This enum is marked as non-exhaustive
Non-exhaustive enums could have additional variants added in future. Therefore, when matching against variants of non-exhaustive enums, an extra wildcard arm must be added to account for any future variants.
WrongKind(Kind)
The wrapping event was not kind: 27235.
MissingUrl
u tag was absent.
MissingMethod
method tag was absent.
InvalidUrl(UrlError)
u tag value did not parse.
InvalidPayloadHashLength(usize)
payload hex was the wrong length.
InvalidPayloadHash(HexError)
payload hex did not decode.
HeaderWrongScheme
Authorization header did not start with Nostr .
HeaderInvalidBase64(DecodeError)
Authorization header body was not parseable base64.
HeaderInvalidUtf8(Utf8Error)
Authorization body decoded to non-UTF-8.
HeaderInvalidEvent(EventError)
Authorization body did not deserialise as a Nostr event.
HeaderInvalidJson(Error)
Authorization body JSON was malformed.
ValidationTimestampSkew
created_at skew exceeded skew_secs.
Fields
ValidationUrlMismatch
u tag did not match the request URL.
ValidationMethodMismatch
method tag did not match the request method.
ValidationPayloadMismatch
SHA-256 of the request body did not match payload.