#[non_exhaustive]pub enum ListingError {
Show 14 variants
WrongKind(Kind),
MissingIdentifier,
WrongPriceTag,
MalformedPrice,
WrongImageTag,
MalformedImage,
MalformedEventRef,
MalformedAddressRef,
InvalidEventId(EventIdError),
InvalidCoordinate(CoordinateError),
InvalidRelayUrl(RelayUrlError),
InvalidUrl(UrlError),
InvalidDim(ImageError),
InvalidTimestamp(TimestampError),
}Expand description
Errors raised by NIP-99 parsers.
Variants (Non-exhaustive)
This enum is marked as non-exhaustive
Non-exhaustive enums could have additional variants added in future. Therefore, when matching against variants of non-exhaustive enums, an extra wildcard arm must be added to account for any future variants.
WrongKind(Kind)
The event was neither kind: 30402 nor kind: 30403.
MissingIdentifier
d tag is absent.
WrongPriceTag
price tag head was not price.
MalformedPrice
price tag is missing the amount or currency column.
WrongImageTag
image tag head was not image.
MalformedImage
image tag is missing the URL column.
MalformedEventRef
e reference tag is missing the event id column.
MalformedAddressRef
a reference tag is missing the coordinate column.
InvalidEventId(EventIdError)
Wrapped event-id parser error.
InvalidCoordinate(CoordinateError)
Wrapped coordinate parser error.
InvalidRelayUrl(RelayUrlError)
Wrapped relay-url parser error.
InvalidUrl(UrlError)
Wrapped URL parser error.
InvalidDim(ImageError)
Wrapped image-dim parser error.
InvalidTimestamp(TimestampError)
Wrapped published_at timestamp parser error.